@@ -1,5 +1,5 @@
 ##############################################################################
-# Copyright 2021 SoundHound, Incorporated.  All rights reserved.
+# Copyright 2022 SoundHound, Incorporated.  All rights reserved.
 ##############################################################################
 import base64
 import hashlib
@@ -24,7 +24,7 @@ except ImportError:
 TEXT_ENDPOINT = "https://api.houndify.com/v1/text"
 VOICE_ENDPOINT = "https://api.houndify.com/v1/audio"
 TRANSCRIPTION_ENDPOINT = "https://api.houndify.com/v1/transcription"
-VERSION = "2.0.7"
+VERSION = "2.0.8"
 
 
 class HoundifySDKError(Exception):
@@ -34,13 +34,14 @@ class HoundifySDKError(Exception):
 
 
 class HoundifyTimeoutError(HoundifySDKError):
-  pass
+  def __init__(self, other):
+    super(HoundifyTimeoutError, self).__init__(other)
 
 
 
 class _BaseHoundClient(object):
 
-    def __init__(self, clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout):
+    def __init__(self, clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout, saveQuery):
       self.clientID = clientID
       self.clientKey = base64.urlsafe_b64decode(clientKey)
       self.userID = userID
@@ -55,6 +56,7 @@ class _BaseHoundClient(object):
       self.proxyHeaders = proxyHeaders
       self.gzip = True
       self.timeout = timeout
+      self.saveQuery = saveQuery
 
       self.HoundRequestInfo = {
         "ClientID": clientID,
@@ -122,9 +124,15 @@ class _BaseHoundClient(object):
       }
 
       if "InputLanguageEnglishName" in requestInfo:
-          headers["Hound-Input-Language-English-Name"] = requestInfo["InputLanguageEnglishName"]
+        headers["Hound-Input-Language-English-Name"] = requestInfo["InputLanguageEnglishName"]
       if "InputLanguageIETFTag" in requestInfo:
-          headers["Hound-Input-Language-IETF-Tag"] = requestInfo["InputLanguageIETFTag"]
+        headers["Hound-Input-Language-IETF-Tag"] = requestInfo["InputLanguageIETFTag"]
+
+      if self.gzip:
+        headers["Hound-Response-Accept-Encoding"] = "gzip"
+
+      if not self.saveQuery:
+        headers["Hound-Extra-Options"] = '{"DoNotSave": ["all"], "DoNotLabel": true}'
 
       return headers, requestInfoString
 
@@ -135,9 +143,9 @@ class TextHoundClient(_BaseHoundClient):
     TextHoundClient is used for making text queries for Hound
     """
     def __init__(self, clientID, clientKey, userID, requestInfo = dict(), endpoint = TEXT_ENDPOINT,
-      proxyHost = None, proxyPort = None, proxyHeaders = None, timeout = None):
+      proxyHost = None, proxyPort = None, proxyHeaders = None, timeout = None, saveQuery = True):
 
-      _BaseHoundClient.__init__(self, clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout)
+      _BaseHoundClient.__init__(self, clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout, saveQuery)
       self.HoundRequestInfo.update(requestInfo)
 
 
@@ -148,8 +156,6 @@ class TextHoundClient(_BaseHoundClient):
       query is the string of the query
       """
       headers, requestInfoString = self._generateHeaders(self.HoundRequestInfo)
-      if self.gzip:
-        headers["Hound-Response-Accept-Encoding"] = "gzip";
 
       if self.proxyHost:
         conn = http.client.HTTPSConnection(self.proxyHost, self.proxyPort)
@@ -164,14 +170,13 @@ class TextHoundClient(_BaseHoundClient):
 
       raw_response = resp.read()
 
-      try:
-        if self.gzip:
-          raw_response = gzip.decompress(raw_response)
-        return json.loads(raw_response.decode("utf-8"))
-      except:
-        pass
+      if resp.getheader("Hound-Response-Content-Encoding") == "gzip":
+        raw_response = gzip.decompress(raw_response)
 
-      raise HoundifySDKError(message = raw_response.decode("utf-8"))
+      try:
+        return json.loads(raw_response.decode("utf-8"))
+      except json.JSONDecodeError:
+        raise HoundifySDKError(message="Invalid ID or Key")
 
 
 
@@ -220,12 +225,12 @@ class StreamingHoundClient(_BaseHoundClient):
     server and receive live transcriptions back
     """
     def __init__(self, clientID, clientKey, userID, requestInfo = dict(), endpoint = VOICE_ENDPOINT, sampleRate = 16000, enableVAD = False,
-      useSpeex = False, proxyHost = None, proxyPort = None, proxyHeaders = None, timeout = None):
+      useSpeex = False, proxyHost = None, proxyPort = None, proxyHeaders = None, timeout = None, saveQuery = True):
       """
       clientID and clientKey are "Client ID" and "Client Key"
       from the Houndify.com web site.
       """
-      _BaseHoundClient.__init__(self, clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout)
+      _BaseHoundClient.__init__(self, clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout, saveQuery)
 
       self.sampleRate = sampleRate
       self.useSpeex = useSpeex
@@ -274,8 +279,6 @@ class StreamingHoundClient(_BaseHoundClient):
 
         headers, requestInfoString = self._generateHeaders(self.HoundRequestInfo)
         headers["Transfer-Encoding"] = "chunked";
-        if self.gzip:
-          headers["Hound-Response-Accept-Encoding"] = "gzip";
 
         for header in headers:
           self.conn.putheader(header, headers[header])
@@ -401,7 +404,8 @@ class StreamingHoundClient(_BaseHoundClient):
         try:
           line = gen.send(chunk_size)
 
-          if self.gzip and line[:3] == b"\x1f\x8b\x08":
+          # Uses gzip magic numbers to check that the byte chunk is compressed
+          if self.gzip and line[:2] == b"\x1f\x8b":
             line = gzip.decompress(line)
 
           line = line.decode("utf-8")
